==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/xivdiag/linux.py <==
#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os import path, environ
from commands import getoutput
from subprocess import PIPE, Popen

from interfaces import IXIVDiag
from collector.collectable.files import SimpleFileCollectable as FileItem
from collector.collectable.commands import SimpleCommandCollectable as CommandItem
from collector.collectable.directories import SimpleDirectoryCollectable as DirectoryItem

DEFAULTDIR = '%stmp' % (path.sep)
HOST_ATTACH_DIR = path.join('/', 'opt', 'xiv', 'host_attach')
HOST_ATTACH_LOGDIR = path.join(HOST_ATTACH_DIR, 'var', 'log')
HOST_ATTACH_BINDIR = path.join(HOST_ATTACH_DIR, 'bin')
HOST_ATTACH_FC = path.join(HOST_ATTACH_BINDIR, 'host_attach_fc')
HOST_ATTACH_ISCSI = path.join(HOST_ATTACH_BINDIR, 'host_attach_iscsi')

class XIVDiag(IXIVDiag):
    def add_collectables(self):
        self.add_directories()
        self.add_files()
        self.add_commands()

    def add_directories(self):
        self.add_collectable_item(DirectoryItem('/var/log directory', self.zip_file, path.join('/', 'var', 'log')))
        self.add_collectable_item(DirectoryItem('/sys directory', self.zip_file, path.join('/', 'sys')))
        self.add_collectable_item(DirectoryItem('/proc directory', self.zip_file, path.join('/', 'proc'), False, '*', ["kcore", "kmsg"]))
        self.add_collectable_item(DirectoryItem('/proc/scsi directory', self.zip_file, path.join('/', 'proc', 'scsi'), True))

    def add_files(self):
        self.add_collectable_item(FileItem('multipath.conf', self.zip_file, path.join('/', 'etc', 'multipath.conf')))
        self.add_collectable_item(FileItem('host_attach log', self.zip_file, path.join(HOST_ATTACH_LOGDIR, 'host_attach')))

    def add_commands(self):
        self.add_collectable_item(CommandItem("xiv_devlist", [path.join('/', 'opt', 'xiv', 'host_attach', 'bin', 'xiv_devlist'), '']))
        self.add_collectable_item(CommandItem("multipath", ['multipath', '-ll']))
        self.add_collectable_item(CommandItem("ls scsi devices", ['ls', '-lR %s' % path.join('/','sys','bus','scsi','*')]))
        self.add_collectable_item(CommandItem("fdisk -l", ['fdisk', '-l']))
        self.add_collectable_item(CommandItem("lspci", ['lspci', '']))
        self.add_collectable_item(CommandItem("mount", ['mount', '']))
        self.add_collectable_item(CommandItem("lsmod", ['lsmod', '']))
        self.add_collectable_item(CommandItem("df", ['df', '']))
        self.add_collectable_item(CommandItem("uname -a", ['uname', '-a']))
        self.add_collectable_item(CommandItem("dmidecode", ['dmidecode','']))
        self.add_collectable_item(CommandItem("ls /dev", ['ls', '-la %s' % path.join('/','dev')]))
        self.add_collectable_item(CommandItem("rpm -qa host_attach", ['rpm', '-qa host_attach']))

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/xivdiag/linux.py <==
#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program  
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
# 
#-------------------------------------------------------------------------------------------------   

from os import path, environ
from commands import getoutput
from subprocess import PIPE, Popen

from interfaces import IXIVDiag
from collector.collectable.files import SimpleFileCollectable as FileItem
from collector.collectable.commands import SimpleCommandCollectable as CommandItem
from collector.collectable.directories import SimpleDirectoryCollectable as DirectoryItem

DEFAULTDIR = '%stmp' % (path.sep)
HOST_ATTACH_DIR = path.join('/', 'opt', 'xiv', 'host_attach')
HOST_ATTACH_LOGDIR = path.join(HOST_ATTACH_DIR, 'log')
HOST_ATTACH_BINDIR = path.join(HOST_ATTACH_DIR, 'bin')
HOST_ATTACH_FC = path.join(HOST_ATTACH_BINDIR, 'host_attach_fc')
HOST_ATTACH_ISCSI = path.join(HOST_ATTACH_BINDIR, 'host_attach_iscsi')

class XIVDiag(IXIVDiag):
    def add_collectables(self):
        self.add_directories()
        self.add_files()
        self.add_commands()

    def add_directories(self):
        self.add_collectable_item(DirectoryItem('/var/log directory', self.zip_file, path.join('/', 'var', 'log')))
        self.add_collectable_item(DirectoryItem('/sys directory', self.zip_file, path.join('/', 'sys')))
        self.add_collectable_item(DirectoryItem('/proc directory', self.zip_file, path.join('/', 'proc'), False, '*', ["kcore", "kmsg"]))
        self.add_collectable_item(DirectoryItem('/proc/scsi directory', self.zip_file, path.join('/', 'proc', 'scsi'), True))

    def add_files(self):
        self.add_collectable_item(FileItem('multipath.conf', self.zip_file, path.join('/', 'etc', 'multipath.conf')))
        self.add_collectable_item(FileItem('host_attach.log', self.zip_file, path.join(HOST_ATTACH_LOGDIR, 'host_attach.log')))

    def add_commands(self):
        self.add_collectable_item(CommandItem("xiv_devlist", [path.join('/', 'opt', 'xiv', 'host_attach', 'bin', 'xiv_devlist'), '']))
        self.add_collectable_item(CommandItem("multipath", ['multipath', '-ll']))
        self.add_collectable_item(CommandItem("ls scsi devices", ['ls', '-lR %s' % path.join('/','sys','bus','scsi','*')]))
        self.add_collectable_item(CommandItem("fdisk -l", ['fdisk', '-l']))
        self.add_collectable_item(CommandItem("lspci", ['lspci', '']))
        self.add_collectable_item(CommandItem("mount", ['mount', '']))
        self.add_collectable_item(CommandItem("lsmod", ['lsmod', '']))
        self.add_collectable_item(CommandItem("df", ['df', '']))
        self.add_collectable_item(CommandItem("uname -a", ['uname', '-a']))
        self.add_collectable_item(CommandItem("dmidecode", ['dmidecode','']))
        self.add_collectable_item(CommandItem("ls /dev", ['ls', '-la %s' % path.join('/','dev')]))
        self.add_collectable_item(CommandItem("rpm -qa host_attach", ['rpm', '-qa host_attach']))
